# define rhver to correspond to either CentOS/RHEL or Fedora version
%if 0%{?rhel}
%global rhver %{rhel}
%endif
%if 0%{?fedora}
%global rhver %{fedora}
%endif
# just in case conditionals weren't working in CentOS/RHEL 5
%if 0
%global rhver 5
%endif

Summary:        GhiaPet package repositories
Name:           ghiapet-repos
Version:        26.1
Release:        1%{?dist}
License:        MIT
Group:          System Environment/Base
URL:            http://www.ghiapet.net/
Vendor:         GhiaPet RPMs <http://www.ghiapet.net/>
%if 0%{?rhel}
Distribution:   GhiaPet RPMs for CentOS/RHEL %{?rhver}
%else
Distribution:   GhiaPet RPMs for Fedora %{?rhver}
%endif
Source:         %{name}-%{version}.tar.bz2
Provides:       ghiapet-repos(%{version})
%if 0%{?rhel} > 5
# Requires:       system-release(%{version})
Requires:       system-release
%endif
%if 0%{?fedora}
Requires:       system-release
%endif
Obsoletes:      ghiapet-release-add < 26
BuildArch:      noarch

%description
GhiaPet package repository files for yum and dnf along with gpg public keys


%package local
Summary:        GhiaPet local package repositories
Conflicts:      ghiapet-release-add < 26

%description local
GhiaPet package repository files for yum/dnf mirrors on my own local network

%prep
%setup -q

%build

%install
# Install the keys
install -d -m 755 $RPM_BUILD_ROOT/etc/pki/rpm-gpg
# install -m 644 RPM-GPG-KEY* $RPM_BUILD_ROOT/etc/pki/rpm-gpg/
%__cp -a RPM-GPG-KEY* $RPM_BUILD_ROOT/etc/pki/rpm-gpg/

# Link the primary/secondary keys to arch files, according to archmap.
# Ex: if there's a key named RPM-GPG-KEY-ghiapet-19-primary, and archmap
#     says "ghiapet-19-primary: i386 x86_64",
#     RPM-GPG-KEY-ghiapet-19-{i386,x86_64} will be symlinked to that key.
pushd $RPM_BUILD_ROOT/etc/pki/rpm-gpg/
for keyfile in RPM-GPG-KEY*; do
    key=${keyfile#RPM-GPG-KEY-} # e.g. 'ghiapet-20-primary'
    arches=$(sed -ne "s/^${key}://p" $RPM_BUILD_DIR/%{name}-%{version}/archmap) \
        || echo "WARNING: no archmap entry for $key"
    for arch in $arches; do
        # replace last part with $arch (ghiapet-20 -> ghiapet-20-$arch)
        ln -s $keyfile ${keyfile}-$arch # NOTE: RPM replaces %% with %
    done
done
# and add symlink for compat generic location
ln -s RPM-GPG-KEY-ghiapet-%{?rhver} RPM-GPG-KEY-%{?rhver}-ghiapet
ln -s RPM-GPG-KEY-ghiapet-%{?rhver} RPM-GPG-KEY-ghiapet
popd

install -d -m 755 $RPM_BUILD_ROOT/etc/yum.repos.d
for file in ghiapet*.repo local*.repo ; do
  install -m 644 $file $RPM_BUILD_ROOT/etc/yum.repos.d
done


%files
%defattr(-,root,root,-)
# %%dir /etc/yum.repos.d
%config(noreplace) /etc/yum.repos.d/ghiapet.repo
%config(noreplace) /etc/yum.repos.d/ghiapet-testing.repo
# %%dir /etc/pki/rpm-gpg
/etc/pki/rpm-gpg/*

%files local
%defattr(-,root,root,-)
%config(noreplace) /etc/yum.repos.d/local.repo
%config(noreplace) /etc/yum.repos.d/local-updates.repo

%changelog
* Sun Jul 23 2017 J. Randall Owens <jrowens@ghiapet.net> - 26.1-1
- update to version 26.1
- use individual files instead of hardlinks
- mostly just to keep etckeeper happy

* Tue Jul 11 2017 J. Randall Owens <jrowens@ghiapet.net> - 26-6
- retain file modification times

* Sat Jul  8 2017 J. Randall Owens <jrowens@ghiapet.net> - 26-5
- reset from new keys to old existing ones
- add subpackage for local mirrors
- better dist release conditional logic

* Fri Jul  7 2017 J. Randall Owens <jrowens@ghiapet.net> - 26-4
- update CentOS/EL 5 key

* Fri Jul  7 2017 J. Randall Owens <jrowens@ghiapet.net> - 26-3
- merge CentOS/EL 5 stuff with conditionals
- fix symlinking

* Fri Jul  7 2017 J. Randall Owens <jrowens@ghiapet.net> - 26-2
- system-release doesn't exist in CentOS/EL 5

* Fri Jul  7 2017 J. Randall Owens <jrowens@ghiapet.net> - 26-1
- update to release Fedora/GhiaPet 26
- new GPG keys, but will have to sign this package with the old key

* Wed Nov 23 2016 J. Randall Owens <jrowens@ghiapet.net> - 25-1
- update to release Fedora/GhiaPet 25

* Thu Jun 23 2016 J. Randall Owens <jrowens@ghiapet.net> - 24-1
- update to release Fedora/GhiaPet 24

* Sun Nov 22 2015 J. Randall Owens <jrowens@ghiapet.net> - 23-1
- update to release Fedora/GhiaPet 23

* Fri Aug 21 2015 J. Randall Owens <jrowens@ghiapet.net> - 22-1
- update to release Fedora/GhiaPet 22

* Mon Jan 12 2015 J. Randall Owens <jrowens@ghiapet.net> - 21-3
- fix symlink to point to new key filename

* Fri Dec 19 2014 J. Randall Owens <jrowens@rs4.ghiapet.net> - 21-2
- fix RPM GPG key filename

* Wed Dec 10 2014 J. Randall Owens <jrowens@rs4.ghiapet.net> - 21-1
- adapt from fedora-repos for ghiapet-repos

* Sat Nov 22 2014 Dennis Gilmore <dennis@ausil.us> 21-2
- Obsolete fedora-repos-anaconda < 21-1
- due to initial confusion over it some people got it installed

* Tue Nov 18 2014 Dennis Gilmore <dennis@ausil.us> 21-1
- drop no longer needed fedora-repos-anaconda sup-package
- disable updates-testing
- turn on 7 day metadata expire for the fedora repo

* Mon Sep 15 2014 Dennis Gilmore <dennis@ausil.us> 21-0.7
- enable the product repos so anaconda will use them

* Wed Sep 10 2014 Dennis Gilmore <dennis@ausil.us> 21-0.6
- add repo files for the products

* Tue Jul 08 2014 Dennis Gilmore <dennis@ausil.us> 21-0.5
- setup for f21 being branched

* Tue Jul 08 2014 Dennis Gilmore <dennis@ausil.us> 21-0.4
- Require fedora-repos-rawhide from main package
- have fedora-repos-rawhide obsolete fedora-release-rawhide

* Tue Jul 08 2014 Dennis Gilmore <dennis@ausil.us> 21-0.3
- remove %%clean and rm in %%install
- Provides:       fedora-repos(%%{version})
- Requires:       system-release(%%{version})
- change url to git repo
- add note on how to make a tarball

* Tue Jul 08 2014 Dennis Gilmore <dennis@ausil.us> 21-0.2
- use %%{version} not %%{dist_version} in symlink command

* Tue Jul 08 2014 Dennis Gilmore <dennis@ausil.us> 21-0.1
- Initial setup for fedora-repos
